@@ -2,7 +2,7 @@
 
 import sys
 
-from clidriver import main
+from cloudonecli.clidriver import main
 
 
 if __name__ == "__main__":
