@@ -8,8 +8,8 @@ class Session():
     def __init__(self):
         self._config = configparser.ConfigParser()
         self._creds = configparser.ConfigParser()
-        self._config.read(os.path.expanduser('~') + '/.cloudone/config')
-        self._creds.read(os.path.expanduser('~') + '/.cloudone/credentials')
+        self._config.read(os.path.expanduser('~') + '/.thus/config')
+        self._creds.read(os.path.expanduser('~') + '/.thus/credentials')
 
     def BuildDSMConfig(self, profile):
         self._configuration = config.Config()
